﻿using System;
using Ivi.Driver.Interop;
using Agilent.Agilent34970.Interop;

//using System.Collections.Generic;
//using System.Linq;
//using System.Text;

namespace _34970A_scan_and_display
{
    /// <summary>
    /// Agilent IVI-COM Driver Example Program
    /// 
    ///
    /// Creates a driver object, reads a few IIviDriver.Identity interface
    /// properties, initializes the driver, checks the instrument error queue,
    /// and closes the driver.
    /// Additional instrument specific functionality:
    /// 
    /// Measures DC Voltage on several mux channels.
    /// Channel 101 reading is displayed for each scan.
    /// 
    /// Runs in simulation mode without an instrument.
    /// 
    /// Requires a COM reference to the driver's type library.
    /// 
    /// </summary>
    public class App
    {
        [STAThread]
        public static void Main(string[] args)
        {
            Agilent.Agilent34970.Interop.Agilent34970 driver = null;  // Version independent

            try
            {
                // Create driver instance
                driver = new Agilent.Agilent34970.Interop.Agilent34970();

               
                // Setup VISA resource descriptor.  Ignored if option Simulate=true
                string resourceDesc;
                resourceDesc = "GPIB0::5::INSTR";
                

                // Setup IVI-defined initialization options
                string standardInitOptions = "QueryInstrStatus=true, Simulate=false";

                // Setup driver-specific initialization options
                string driverSetupOptions = "DriverSetup= Model=, Trace=false";

                driver.Initialize(resourceDesc, true, true, standardInitOptions + "," + driverSetupOptions);
                //Console.WriteLine("  Driver Initialized");


                // IIviDriverIdentity properties - Initialize required
                string instModel = driver.Identity.InstrumentModel;
                //Console.WriteLine("InstrumentModel: {0}", instModel);

                string instFirmwareRevision = driver.Identity.InstrumentFirmwareRevision;
                //Console.WriteLine("InstrumentFirmwareRevision: {0}", instFirmwareRevision);

                string instManufacturer = driver.Identity.InstrumentManufacturer;
                //Console.WriteLine("InstrumentManufacturer: {0}\n", instManufacturer);

                            

                // Setup and measure DC voltage on 34901A mux channels 1-10
                int muxSlot = 100;
                if (muxSlot != 0)
                {
                    
                    int firstChannel = muxSlot + 1; // Channel 1 on mux card
                    int lastChannel = muxSlot + 10; // Channel 10 on mux card
                    string scanList = firstChannel.ToString() + ":" + lastChannel.ToString(); // Scan list channels 1-5
                    string[] data;

                    driver.Voltage.DCVoltage.Configure(scanList, 10, 0.01);
                    driver.Voltage.DCVoltage.NPLCListConfig(scanList, 0.02);

                    for (int i = 1; i <= 20; i++)
                    {
                        data = driver.Scan.Read();

                        // Read data from instrument memory.  Data is returned as an array of strings.

                        Console.Write("{0}, ", data[1]);
                        Console.WriteLine();
                        //Wait 1 second - however you do that
                    }
                }
                else
                    Console.WriteLine("34901A Mux Module not found\n");


                // Check instrument for errors
                int errorNum = -1;
                string errorMsg = null;
                Console.WriteLine("");
                while (errorNum != 0)
                {
                    driver.Utility.ErrorQuery(ref errorNum, ref errorMsg);
                    Console.WriteLine("ErrorQuery: {0}, {1}", errorNum, errorMsg);
                }

            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                if (ex.Message.IndexOf("Instrument error detected.") != -1)
                {
                    // Check instrument for errors
                    int errorNum = -1;
                    string errorMsg = null;
                    Console.WriteLine("");
                    while (errorNum != 0)
                    {
                        driver.Utility.ErrorQuery(ref errorNum, ref errorMsg);
                        Console.WriteLine("ErrorQuery: {0}, {1}", errorNum, errorMsg);
                    }
                }
            }
            finally
            {
                if (driver != null && driver.Initialized)
                {
                    // Close driver
                    driver.Close();
                    Console.WriteLine("  Driver Closed");
                }
            }
            Console.WriteLine("\nDone - Press Enter to Exit");
            Console.ReadLine();
        }
    }
}
